/**
 * The failure error used internally to track error types and status.
 */
export declare class HypervalError extends Error {
    readonly source: any;
    readonly path: string[];
    readonly validation: string;
    /**
     * Create new HypervalError
     *
     * @param source Source data where the error occurred.
     * @param path Path on source where the error occurred.
     * @param validation The name of the validation error.
     */
    constructor(source: any, path: string[], validation: string);
    /**
     * Returns the full error result. Suitable for printing and debugging.
     */
    get full(): string;
}
/**
 * Trace where validation errors occur.
 */
export declare class Trace {
    private root;
    private prev;
    private current;
    /**
     * Create new Trace
     *
     * @param root Source data where the validation begins.
     */
    constructor(root: any);
    /**
     * Create new Trace
     *
     * @param root Source data where the validation begins.
     * @param prev Parent node.
     */
    constructor(root: any, prev: Trace);
    /**
     * Create new Trace
     *
     * @param root Source data where the validation begins.
     * @param prev Parent node.
     * @param current Current node name.
     */
    constructor(root: any, prev: undefined | Trace, current: string);
    /**
     * Split the trace path. Used when going down an object or array level.
     *
     * @param name Name of forked path.
     * @returns `Trace` New copy of trace for the forked path.
     */
    fork(name: any): Trace;
    /**
     * Throws a HypervalError error at the current path of the trace.
     *
     * @param error Error to throw.
     */
    throw(error: string): never;
}
