import type { Hyper } from './Hyper';
import { HypervalError } from './Trace';
/**
 * Sets the hypeval test to the apply function,
 * returning a curried `apply` function to add data to.
 *
 * @param hyperval Hyperval test to check raw with.
 * @returns Curried `apply` function
 */
export declare function apply<T, U>(hyperval: Hyper<T, U>): 
/**
 * Checks a value, applying any alter and cast modifications.
 * Returns a copy with altered and casted data.
 * Does not mutate original but may refer back to it.
 *
 * @param raw Raw value.
 * @returns Checked Value
 */
(raw: T) => U;
/**
 * Checks a value, applying any alter and cast modifications.
 * Returns a copy with altered and casted data.
 * Does not mutate original but may refer back to it.
 *
 * @param hyperval Hyperval test to check raw with.
 * @param raw Raw value.
 * @returns Checked Value
 */
export declare function apply<T, U>(hyperval: Hyper<T, U>, raw: T): U;
/**
 * Sets the hypeval test to the assert function,
 * returning a curried `assert` function to add data to.
 *
 * @param hyperval Hyperval test to check raw with.
 * @returns Curried `assert` function
 */
export declare function assert<T, U>(hyperval: Hyper<T, U>): 
/**
 * Asserts a value. Alter and cast modifications are still applied to an unused copy in the background as part of this process.
 * Original value remains unaltered. If used with data that has cast and alter modifications, asserted data may be incorrect.
 *
 * @param raw Raw value.
 * @returns Checked Value
 */
(raw: T) => asserts raw is T;
/**
 * Asserts a value. Alter and cast modifications are still applied to an unused copy in the background as part of this process.
 * Original value remains unaltered. If used with data that has cast and alter modifications, asserted data may be incorrect.
 *
 * @param hyperval Hyperval test to check raw with.
 * @param raw Raw value.
 * @returns Checked Value
 */
export declare function assert<T, U>(hyperval: Hyper<T, U>, raw: T): asserts raw is T;
/**
 * Sets the hypeval test to the is function,
 * returning a curried `is` function to add data to.
 *
 * @param hyperval Hyperval test to check raw with.
 * @returns Curried `is` function
 */
export declare function is<T, U>(hyperval: Hyper<T, U>): 
/**
 * Typeguard a value. Alter and cast modifications are still applied to an unused copy in the background as part of this process.
 * Original value remains unaltered. If used with data that has cast and alter modifications, asserted data may be incorrect.
 *
 * @param raw Raw value.
 * @returns Checked Value
 */
(raw: T) => raw is T;
/**
 * Typeguard a value. Alter and cast modifications are still applied to an unused copy in the background as part of this process.
 * Original value remains unaltered. If used with data that has cast and alter modifications, asserted data may be incorrect.
 *
 * @param hyperval Hyperval test to check raw with.
 * @param raw Raw value.
 * @returns Checked Value
 */
export declare function is<T, U>(hyperval: Hyper<T, U>, raw: T): raw is T;
/**
 * Sets the hypeval test to the validate function,
 * returning a curried `validate` function to add data to.
 *
 * @param hyperval Hyperval test to check raw with.
 * @returns Curried `validate` function
 */
export declare function validate<T, U>(hyperval: Hyper<T, U>): 
/**
 * Validates a value, applying any alter and cast modifications.
 * Returns a copy with altered and casted data.
 * Does not mutate original but may refer back to it.
 *
 * @param raw Raw value.
 * @returns Checked Value
 */
(raw: T) => {
    error?: undefined;
    result: U;
} | {
    error: HypervalError;
    result?: undefined;
};
/**
 * Validates a value, applying any alter and cast modifications.
 * Returns a copy with altered and casted data.
 * Does not mutate original but may refer back to it.
 *
 * @param hyperval Hyperval test to check raw with.
 * @param raw Raw value.
 * @returns Checked Value
 */
export declare function validate<T, U>(hyperval: Hyper<T, U>, raw: T): {
    error?: undefined;
    result: U;
} | {
    error: HypervalError;
    result?: undefined;
};
