"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.object_core = exports.HyperObject = exports.is_object = void 0;
const Hyper_1 = require("../Hyper");
const optional_1 = require("../modifier/optional");
/* End adapted code */
function is_object(raw, failure) {
    if (raw === null || typeof raw !== 'object' || Array.isArray(raw))
        failure.throw('Is not object');
}
exports.is_object = is_object;
class HyperObject extends Hyper_1.Hyper {
    constructor(
    /**
     * Object schema
     */
    schema, ...hyper) {
        super(...hyper);
        this.schema = schema;
    }
}
exports.HyperObject = HyperObject;
function object_core(check_length, value) {
    const keys = new Set(Object.keys(value));
    return new HyperObject(value, 'object', function (raw, failure) {
        is_object(raw, failure);
        if (check_length) {
            const raw_keys = Object.keys(raw);
            for (const key of raw_keys) {
                if (!keys.has(key))
                    failure.fork(key).throw('Object has extra keys');
            }
        }
        const result = Object.assign({}, raw);
        for (const key of keys) {
            if (!raw.hasOwnProperty(key)) {
                if (!(value[key] instanceof optional_1.HyperOptional))
                    failure.fork(key).throw('Object is missing keys');
                try {
                    value[key].hyper(undefined, failure.fork(key));
                }
                catch (_a) {
                    failure.fork(key).throw('Object is missing keys');
                }
            }
            result[key] = value[key].hyper(raw[key], failure.fork(key));
            if (value[key] instanceof optional_1.HyperOptional && result[key] === undefined)
                delete result[key];
        }
        return result;
    });
}
exports.object_core = object_core;
