import type { HyperConstructor, HyperRaw, HyperVal } from '../Hyper';
import { Hyper } from '../Hyper';
export declare class HyperRecord<T extends Hyper<string>, U extends Hyper<any, any>> extends Hyper<{
    [K in HyperRaw<T>]?: HyperRaw<U>;
}, {
    [K in HyperVal<T>]?: HyperVal<U>;
}> {
    /**
     * Record Schema
     */
    readonly schema: {
        /** Key */
        key: T;
        /** Value */
        val: U;
    };
    constructor(
    /**
     * Record Schema
     */
    schema: {
        /** Key */
        key: T;
        /** Value */
        val: U;
    }, ...hyper: HyperConstructor<{
        [K in HyperVal<T>]?: HyperVal<U>;
    }>);
}
export declare class HyperLooseRecord<T extends Hyper<string>, U extends Hyper<any, any>> extends Hyper<{
    [K in HyperRaw<T>]: HyperRaw<U>;
}, {
    [K in HyperVal<T>]: HyperVal<U>;
}> {
    /**
     * Record Schema
     */
    readonly schema: {
        /** Key */
        key: T;
        /** Value */
        val: U;
    };
    constructor(
    /**
     * Record Schema
     */
    schema: {
        /** Key */
        key: T;
        /** Value */
        val: U;
    }, ...hyper: HyperConstructor<{
        [K in HyperVal<T>]: HyperVal<U>;
    }>);
}
/**
 * Validates a value to be a generic object of `{ [key]: value }`
 *
 * @param keyhyper Key value.
 * @param valhyper Data value.
 */
export declare function record<T extends Hyper<string>, U extends Hyper<any, any>>(keyhyper: T, valhyper: U): HyperLooseRecord<T, U>;
/**
 * Validates a value to be a generic object of `{ [key]: value }`
 *
 * @param keyhyper Key value.
 * @param valhyper Data value.
 * @param loose Set this to 'loose' to prevent assumption that key access is possibly null.
 * @deprecated This is the current default
 */
export declare function record<T extends Hyper<string>, U extends Hyper<any, any>>(keyhyper: T, valhyper: U, loose: 'loose'): HyperLooseRecord<T, U>;
/**
 * Validates a value to be a generic object of `{ [key]?: value }`
 * This variant adds a default optional type on the key.
 *
 * @param keyhyper Key value.
 * @param valhyper Data value.
 * @param strict Set this to 'strict' to assume all keys to possibly null.
 */
export declare function record<T extends Hyper<string>, U extends Hyper<any, any>>(keyhyper: T, valhyper: U, strict: 'strict'): HyperRecord<T, U>;
