import type { HyperConstructor, HyperRaw, HyperVal } from '../Hyper';
import { Hyper } from '../Hyper';
export declare class HyperAlter<T extends Hyper<any, any>, U> extends Hyper<HyperRaw<T>, U> {
    /** Unalter schema */
    readonly schema: T;
    constructor(
    /** Unalter schema */
    schema: T, ...hyper: HyperConstructor<U>);
}
/**
 * Add test to alter function.
 * The alteration is applied after the test and therefore the argument is typed but the output is not checked.
 * You will need to provide your own type for the alteration argument.
 *
 * @param alter Function to alter result.
 * @returns `(test: Test<T>) => Test<U>` Curried test callback.
 */
export declare function alter<T extends Hyper<any>, U>(alter: (raw: HyperVal<T>) => U): 
/**
 * Alters the result of a test.
 * The alteration is applied after the test and therefore the argument is typed but the output is not checked.
 * You will need to provide your own type for the alteration argument.
 *
 * @param hyper Test to use before alteration.
 * @returns `Test<U>` The resulting test.
 */
<V extends Hyper<any> = T>(hyper: V) => HyperAlter<V, U>;
/**
 * Alters the result of a test.
 * The alteration is applied after the test and therefore the argument is typed but the output is not checked.
 *
 * @param hyper `Test<T>` Test to use before alteration.
 * @param alter Function to alter result.
 * @returns `Test<U>` The resulting test.
 */
export declare function alter<T extends Hyper<any>, U>(hyper: T, alter: (raw: HyperVal<T>) => U): HyperAlter<T, U>;
