import type { HyperConstructor, HyperRaw, HyperVal } from '../Hyper';
import { Hyper } from '../Hyper';
export declare class HyperAugment<T extends Hyper<any, any>, U = T> extends Hyper<HyperRaw<T>, HyperVal<U>> {
    /** Unaugment schema */
    readonly schema: T;
    constructor(
    /** Unaugment schema */
    schema: T, ...hyper: HyperConstructor<HyperVal<U>>);
}
/**
 * Add an augment function to be used on a Hyper
 * The augmentation is applied after the test and will not be run if the initial type check fails.
 * Augmentation does not alter the resulting type. Use {@link cast} for that.
 *
 * @param augment Type guard function to augment result.
 * @returns `(test: Test<T>) => Test<U>` Curried test callback.
 */
export declare function augment<T extends Hyper<any>, U extends HyperVal<T>>(augment: (tested: HyperVal<T>) => tested is U): 
/**
 * Augment the checking of a value after the initial test.
 * The augmentation is applied after the test and will not be run if the initial type check fails.
 * Augmentation does not alter the resulting type. Use {@link cast} for that.
 *
 * @param hyper `Test<T>` Test to use before augmentation.
 * @returns `Test<U>` The resulting test.
 */
(hyper: T) => HyperAugment<T, U>;
/**
 * Augment the checking of a value after the initial test.
 * The augmentation is applied after the test and will not be run if the initial type check fails.
 * Augmentation does not alter the resulting type. Use {@link cast} for that.
 *
 * @param hyper `Test<T>` Test to use before augmentation.
 * @param augment Type guard function to augment result.
 * @returns `Test<U>` The resulting test.
 */
export declare function augment<T extends Hyper<any, any>, U extends HyperVal<T>>(hyper: T, augment: (tested: HyperVal<T>) => tested is U): HyperAugment<T, U>;
/**
 * @deprecated Use type guard instead of boolean
 *
 * Add an augment function to be used on a Hyper
 * The augmentation is applied after the test and will not be run if the initial type check fails.
 * Augmentation does not alter the resulting type. Use {@link cast} for that.
 *
 * @param augment Function to augment result.
 * @returns `(test: Test<T>) => Test<U>` Curried test callback.
 */
export declare function augment<T extends Hyper<any>, U = HyperVal<T>>(augment: (tested: HyperVal<T>) => boolean): 
/**
 * Augment the checking of a value after the initial test.
 * The augmentation is applied after the test and will not be run if the initial type check fails.
 * Augmentation does not alter the resulting type. Use {@link cast} for that.
 *
 * @param hyper `Test<T>` Test to use before augmentation.
 * @returns `Test<U>` The resulting test.
 */
(hyper: T) => HyperAugment<T, U>;
/**
 * @deprecated Use type guard instead of boolean
 *
 * Augment the checking of a value after the initial test.
 * The augmentation is applied after the test and will not be run if the initial type check fails.
 * Augmentation does not alter the resulting type. Use {@link cast} for that.
 *
 * @param hyper `Test<T>` Test to use before augmentation.
 * @param augment Function to augment result.
 * @returns `Test<U>` The resulting test.
 */
export declare function augment<T extends Hyper<any, any>, U = HyperVal<T>>(hyper: T, augment: (tested: HyperVal<T>) => boolean): HyperAugment<T, U>;
