import type { HyperConstructor, HyperRaw, HyperVal } from '../Hyper';
import { Hyper } from '../Hyper';
export declare class HyperCast<T, U extends Hyper<any, any>> extends Hyper<T, HyperVal<U>> {
    /** Uncast schema */
    readonly schema: U;
    constructor(
    /** Uncast schema */
    schema: U, ...hyper: HyperConstructor<HyperVal<U>>);
}
/**
 * Add a cast function to be applied before running a Hyper.
 * The alteration is applied before the test and therefore the argument is untyped but the output will be checked.
 *
 * @param cast Function to cast result.
 * @returns `(hyper: Hyper<T, U>) => Hyper<U, V>` Curried test callback.
 */
export declare function cast<T, U>(cast: (raw: T) => U): 
/**
 * Cast value before running a test.
 * The alteration is applied before the test and therefore the argument is untyped but the output will be checked.
 *
 * @param hyper Test to use after cast.
 * @returns `Test<U>` The resulting test.
 */
<V extends Hyper<any, any>>(hyper: V) => HyperCast<T, V>;
/**
 * Cast value before running a test.
 * The alteration is applied before the test and therefore the argument is untyped but the output will be checked.
 *
 * @param hyper `Test<T>` Test to use after casting.
 * @param cast Function to cast result.
 * @returns `Test<U>` The resulting test.
 */
export declare function cast<T, U extends Hyper<any, any>>(hyper: U, cast: (raw: T) => HyperRaw<U>): HyperCast<T, U>;
