import { Hyper } from '../Hyper';
/**
 * Create a custom validator primitive for hyperval.
 * On successful validation, return `{ result: T }`
 * On validation failure, return `{ errror: string }`
 *
 * The lifecycle of validation applies to the success result.
 * Cast will be applied before the validate function recieves data, alter will be applied after the validation.
 * You may also perform mutations to the result of the validation. It will be applied when the `apply` validation is called.
 *
 * @param validate Custom validation function.
 */
export declare function custom<T extends any, U>(validate: (raw: T) => {
    result: U;
    error?: string;
} | {
    result?: U;
    error: string;
}): Hyper<T, U>;
/**
 * Create a custom validator primitive for hyperval.
 * On successful validation, return `{ result: T }`
 * On validation failure, return `{ errror: string }`
 *
 * The lifecycle of validation applies to the success result.
 * Cast will be applied before the validate function recieves data, alter will be applied after the validation.
 * You may also perform mutations to the result of the validation. It will be applied when the `apply` validation is called.
 *
 * @param name The name of the validation. Shows up during errors.
 * @param validate Custom validation function.
 */
export declare function custom<T extends any, U>(name: string, validate: (raw: T) => {
    result: U;
    error?: string;
} | {
    result?: U;
    error: string;
}): Hyper<T, U>;
