"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.enums = void 0;
const Hyper_1 = require("../Hyper");
const Trace_1 = require("../Trace");
/**
 * Validates value to be part one of the provided values with same-value-zero equality or through its test function.
 *
 * @param value Literal value.
 */
function enums(...value) {
    return Hyper_1.Hyper.new('enum', function test(x, failure) {
        let last_error = [];
        for (let i = 0; i < value.length; i++) {
            try {
                const val = value[i];
                if (val instanceof Hyper_1.Hyper) {
                    return val.hyper(x, failure);
                }
                else {
                    if (val !== x)
                        failure.throw(`${val}`);
                    return val;
                }
            }
            catch (e) {
                if (e instanceof Trace_1.HypervalError) {
                    last_error.push(e);
                }
                else {
                    throw e;
                }
            }
        }
        failure.throw(`Enum: ${value.map(x => x instanceof Hyper_1.Hyper ? JSON.stringify(x.onfail) : JSON.stringify(x)).join('; ')}`);
    });
}
exports.enums = enums;
