import { apply, assert, is, validate } from './Wrap';
/**
 * Base Hyper test class
 */
export class Hyper {
    /**
     * New Hyper Object
     *
     * @param onfail Message to print on failure.
     * @param hyper Hyper test function.
     */
    constructor(
    /** Message to print on failure */
    onfail, 
    /** Hyper test function */
    hyper) {
        this.onfail = onfail;
        this.hyper = hyper;
        this.apply = this.apply.bind(this);
        this.assert = this.assert.bind(this);
        this.is = this.is.bind(this);
        this.validate = this.validate.bind(this);
        this.thenApply = this.thenApply.bind(this);
        this.thenAssert = this.thenAssert.bind(this);
        this.thenIs = this.thenIs.bind(this);
        this.thenValidate = this.thenValidate.bind(this);
        this.anyApply = this.anyApply.bind(this);
        this.anyAssert = this.anyAssert.bind(this);
        this.anyIs = this.anyIs.bind(this);
        this.anyValidate = this.anyValidate.bind(this);
    }
    apply(raw, strict) {
        return apply(this, raw);
    }
    assert(raw, strict) {
        assert(this, raw);
    }
    is(raw, strict) {
        return is(this, raw);
    }
    validate(raw, strict) {
        return validate(this, raw);
    }
    async thenApply(raw, strict) {
        return apply(this, await raw);
    }
    async thenAssert(raw, strict) {
        return assert(this, await raw);
    }
    async thenIs(raw, strict) {
        return is(this, await raw);
    }
    async thenValidate(raw, strict) {
        return validate(this, await raw);
    }
    /**
     * @deprecated Use {@link apply}
     * Checks a value, applying any alter and cast modifications.
     * Returns a copy with altered and casted data.
     * Does not mutate original but may refer back to it.
     *
     * @param raw Raw value.
     * @returns Checked Value
     */
    anyApply(raw) {
        return this.apply(raw);
    }
    /**
     * @deprecated Use {@link assert}
     * Typeguard a value. Alter and cast modifications are still applied to an unused copy in the background as part of this process.
     * Original value remains unaltered. If used with data that has cast and alter modifications, asserted data may be incorrect.
     *
     * @param raw Raw value.
     * @returns Checked Value
     */
    anyAssert(raw) {
        return this.assert(raw);
    }
    /**
     * @deprecated Use {@link is}
     * Typeguard a value. Alter and cast modifications are still applied to an unused copy in the background as part of this process.
     * Original value remains unaltered. If used with data that has cast and alter modifications, asserted data may be incorrect.
     *
     * @param raw Raw value.
     * @returns Checked Value
     */
    anyIs(raw) {
        return this.is(raw);
    }
    /**
     * @deprecated Use {@link validate}
     * Validates a value, applying any alter and cast modifications.
     * Returns a copy with altered and casted data.
     * Does not mutate original but may refer back to it.
     *
     * @param raw Raw value.
     * @returns Checked Value
     */
    anyValidate(raw) {
        return this.validate(raw);
    }
    /**
     * New Hyper Object
     *
     * @param onfail Message to print on failure.
     * @param hyper Hyper test function.
     */
    static new(onfail, test) {
        return new Hyper(onfail, test);
    }
}
/**
 * Generates a generic test function.
 *
 * @param name Name of test.
 * @param test Test function that validates input.
 */
export function hyperval_factory(name, test) {
    const generic = Hyper.new(name, function (raw, failure) {
        if (!test(raw))
            failure.throw(name);
        return raw;
    });
    return generic;
}
