import { Hyper } from '../Hyper';
import { HyperOptional } from '../modifier/optional';
/* End adapted code */
export function is_object(raw, failure) {
    if (raw === null || typeof raw !== 'object' || Array.isArray(raw))
        failure.throw('Is not object');
}
export class HyperObject extends Hyper {
    constructor(
    /**
     * Object schema
     */
    schema, ...hyper) {
        super(...hyper);
        this.schema = schema;
    }
}
export function object_core(check_length, value) {
    const keys = new Set(Object.keys(value));
    return new HyperObject(value, 'object', function (raw, failure) {
        is_object(raw, failure);
        if (check_length) {
            const raw_keys = Object.keys(raw);
            for (const key of raw_keys) {
                if (!keys.has(key))
                    failure.fork(key).throw('Object has extra keys');
            }
        }
        const result = Object.assign({}, raw);
        for (const key of keys) {
            if (!raw.hasOwnProperty(key)) {
                if (!(value[key] instanceof HyperOptional))
                    failure.fork(key).throw('Object is missing keys');
                try {
                    value[key].hyper(undefined, failure.fork(key));
                }
                catch (_a) {
                    failure.fork(key).throw('Object is missing keys');
                }
            }
            result[key] = value[key].hyper(raw[key], failure.fork(key));
            if (value[key] instanceof HyperOptional && result[key] === undefined)
                delete result[key];
        }
        return result;
    });
}
