import { Hyper } from '../Hyper';
export class HyperTuple extends Hyper {
    constructor(
    /**
     * Tuple schema.
     */
    schema, ...hyper) {
        super(...hyper);
        this.schema = schema;
    }
}
/**
 * Validates value to be a tuple.
 *
 * @param hyper Tuple value.
 */
export function tuple(hyper) {
    return new HyperTuple(hyper, 'tuple', function (x, failure) {
        if (!Array.isArray(x))
            failure.throw('Is not array');
        if (x.length !== hyper.length)
            failure.throw('Tuple length mismatch');
        let i = hyper.length;
        const result = new Array(i);
        while (--i >= 0) {
            const t = hyper[i];
            if (t instanceof Hyper) {
                result[i] = t.hyper(x[i], failure.fork(i));
            }
            else {
                if (hyper[i] !== x[i])
                    failure.fork(i).throw(`tuple: ${i}`);
                result[i] = x[i];
            }
        }
        return result;
    });
}
