import { Hyper } from '../Hyper';
import { HypervalError } from '../Trace';
/**
 * Validates value to be part one of the provided values with same-value-zero equality or through its test function.
 *
 * @param value Literal value.
 */
export function enums(...value) {
    return Hyper.new('enum', function test(x, failure) {
        let last_error = [];
        for (let i = 0; i < value.length; i++) {
            try {
                const val = value[i];
                if (val instanceof Hyper) {
                    return val.hyper(x, failure);
                }
                else {
                    if (val !== x)
                        failure.throw(`${val}`);
                    return val;
                }
            }
            catch (e) {
                if (e instanceof HypervalError) {
                    last_error.push(e);
                }
                else {
                    throw e;
                }
            }
        }
        failure.throw(`Enum: ${value.map(x => x instanceof Hyper ? JSON.stringify(x.onfail) : JSON.stringify(x)).join('; ')}`);
    });
}
